@@ -37,6 +37,8 @@ import click
               help='Precision for scan')
 @click.option('-e', '--eps', type=float, default=1.0, show_default=True,
               help='Convergence criterium')
+@click.option('--retry', type=int, default=0, show_default=True,
+              help='Maximum number of retries upon a failed fit')
 @click.option('-l', '--log_level', default="INFO", show_default=True,
               help='Log level')
 @click.option('--print_level', type=int, default=1, show_default=True,
@@ -195,6 +197,8 @@ def plot_pulls(**kwargs):
               help='Minimizer algorithm')
 @click.option('-e', '--eps', type=float, default=1.0, show_default=True,
               help='Convergence criterium')
+@click.option('--retry', type=int, default=0, show_default=True,
+              help='Maximum number of retries upon a failed fit')
 @click.option('--strategy', type=int, default=1, show_default=True,
               help='Default minimization strategy')
 @click.option('--print_level', type=int, default=-1, show_default=True,
@@ -342,6 +346,12 @@ def generate_asimov(**kwargs):
               help='Parameters to profile')
 @click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
               help='Name of initial snapshot')
+@click.option('--asimov_names', default=None, show_default=True,
+              help='Names of the output asimov datasets (separated by commas). If not specified, '
+                   'a default name for the corresponding asimov type will be given.')
+@click.option('--asimov_snapshots', default=None, show_default=True,
+              help='Names of the output asimov snapshots (separated by commas). If not specified, '
+                   'a default name for the corresponding asimov type will be given.')
 @click.option('-t', '--asimov_types', default="0,1,2", show_default=True,
               help='\b\n Types of asimov dataset to generate separated by commas.'
                    '\b\n 0: fit with POI fixed to 0'
@@ -364,13 +374,21 @@ def generate_standard_asimov(**kwargs):
     profile_param = kwargs.pop('profile_param')
     snapshot_name = kwargs.pop('snapshot_name')
     poi_scale = kwargs.pop("poi_scale")
+    asimov_names = kwargs.pop("asimov_names")
+    asimov_snapshots = kwargs.pop("asimov_snapshots")
     config = {
         'fix_param': fix_param,
         'profile_param': profile_param,
         'snapshot_name': snapshot_name
     }
+    if asimov_names is not None:
+        asimov_names = asimov_names.split(",")
+    if asimov_snapshots is not None:
+        asimov_snapshots = asimov_snapshots.split(",")        
     generator = AsimovGenerator(**kwargs, config=config)
-    generator.generate_standard_asimov(asimov_types, poi_scale=poi_scale)
+    generator.generate_standard_asimov(asimov_types, poi_scale=poi_scale,
+                                       asimov_names=asimov_names,
+                                       asimov_snapshots=asimov_snapshots)
     generator.save(outname)
     
 
