@@ -64,6 +64,8 @@ import click
               help='Minimizer algorithm')
 @click.option('-e', '--eps', type=float, default=1.0, show_default=True,
               help='Convergence criterium')
+@click.option('--retry', type=int, default=0, show_default=True,
+              help='Maximum number of retries upon a failed fit')
 @click.option('--strategy', type=int, default=1, show_default=True,
               help='Default minimization strategy')
 @click.option('--print_level', type=int, default=-1, show_default=True,
@@ -119,11 +121,11 @@ def limit_scan_deprecated(**kwargs):
               help='\b\n Parameter name expression describing the internal parameterisation.'
                    '\b\n\n Example: "klambda=-10_10_0.2,k2v=1"'
                    '\b\n Refer to documentation for more information')
-@click.option('-f', '--filter', 'filter_expr', default=None, show_default=True,
+@click.option('--filter', 'filter_expr', default=None, show_default=True,
               help='\b Filter parameter points by expression.\n'
                    '\b Example: "mass=2*,350,400,450;klambda=1.*,2.*,-1.*,-2.*"\n'
                    '\b Refer to documentation for more information\n')
-@click.option('-e', '--exclude', 'exclude_expr', default=None, show_default=True,
+@click.option('--exclude', 'exclude_expr', default=None, show_default=True,
               help='\b Exclude parameter points by expression.\n'
                    '\b Example: "mass=2*,350,400,450;klambda=1.*,2.*,-1.*,-2.*"\n'
                    '\b Refer to documentation for more information\n')
@@ -181,6 +183,8 @@ def limit_scan_deprecated(**kwargs):
               help='Minimizer algorithm')
 @click.option('-e', '--eps', type=float, default=1.0, show_default=True,
               help='Convergence criterium')
+@click.option('--retry', type=int, default=0, show_default=True,
+              help='Maximum number of retries upon a failed fit')
 @click.option('--strategy', type=int, default=1, show_default=True,
               help='Default minimization strategy')
 @click.option('--print_level', type=int, default=-1, show_default=True,
