@@ -10,7 +10,7 @@ class AnalysisObject(AbstractObject):
                  fix_param:str='', profile_param:str='', ws_name:Optional[str]=None, 
                  mc_name:Optional[str]=None, snapshot_name:Optional[Union[List[str], str]]=None,
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', precision:float=0.001, 
-                 eps:float=1.0, strategy:int=1, print_level:int=-1, timer:bool=False,
+                 eps:float=1.0, retry:int=1, strategy:int=1, print_level:int=-1, timer:bool=False,
                  num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
@@ -26,8 +26,8 @@ class AnalysisObject(AbstractObject):
             self.save_snapshot("initialSnapshot")
             self.set_poi(poi_name)
             self.setup_parameters(fix_param, profile_param, update_snapshot=True)
-            self.setup_minimizer(minimizer_type, minimizer_algo, precision, eps, strategy, num_cpu,
-                                 offset, optimize, eigen, max_calls, max_iters, print_level,
+            self.setup_minimizer(minimizer_type, minimizer_algo, precision, eps, retry, strategy,
+                                 num_cpu, offset, optimize, eigen, max_calls, max_iters, print_level,
                                  timer, constrain_nuis, batch_mode, int_bin_precision,
                                  verbosity=verbosity)
     
@@ -69,7 +69,8 @@ class AnalysisObject(AbstractObject):
                 poi = self.model.get_poi(pname)
                 self.poi.add(poi)
                 true_poi_names.append(poi.GetName())
-            self.stdout.info('INFO: POIs set to {}'.format(", ".join([f"\"{name}\"" for name in true_poi_names])))
+            if true_poi_names:
+                self.stdout.info('INFO: POIs set to {}'.format(", ".join([f"\"{name}\"" for name in true_poi_names])))
         else:
             self.poi = self.model.get_poi(poi_name)
             if poi_name is not None:
@@ -95,7 +96,7 @@ class AnalysisObject(AbstractObject):
             self.save_snapshot("currentSnapshot")
             
     def setup_minimizer(self, minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
-                        precision:float=0.001, eps:float=1.0, strategy:int=0, 
+                        precision:float=0.001, eps:float=1.0, retry:int=1, strategy:int=0, 
                         num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
                         max_calls:int=-1, max_iters:int=-1, print_level:int=-1, timer:bool=False,
                         constrain_nuis:bool=True, batch_mode:bool=False, int_bin_precision:float=-1.,
@@ -108,11 +109,13 @@ class AnalysisObject(AbstractObject):
         if (constrain_nuis and self.model.nuisance_parameters):
             #nll_commands.append(ROOT.RooFit.Constrain(self.model.nuisance_parameters))
             nll_commands.append(ROOT.RooFit.GlobalObservables(self.model.global_observables))
-            nll_commands.append(ROOT.RooFit.ConditionalObservables(self.model.model_config.GetConditionalObservables()))
+            conditional_obs = self.model.model_config.GetConditionalObservables()
+            if conditional_obs:
+                nll_commands.append(ROOT.RooFit.ConditionalObservables(conditional_obs))
             #nll_commands.append(ROOT.RooFit.ExternalConstraints(ROOT.RooArgSet()))
-        if hasattr(ROOT.RooFit, "BatchMode"):
+        if (hasattr(ROOT.RooFit, "BatchMode")):
             nll_commands.append(ROOT.RooFit.BatchMode(batch_mode))
-        if hasattr(ROOT.RooFit, "IntegrateBins"):
+        if (hasattr(ROOT.RooFit, "IntegrateBins")):
             nll_commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))
         minimizer_options = {
             'minimizer_type'   : minimizer_type,
@@ -121,6 +124,7 @@ class AnalysisObject(AbstractObject):
             'opt_const'        : optimize,
             'precision'        : precision,
             'eps'              : eps,
+            'retry'            : retry,
             'eigen'            : eigen,
             'max_calls'        : max_calls,
             'max_iters'        : max_iters,
@@ -142,12 +146,13 @@ class AnalysisObject(AbstractObject):
     def set_blind_range(self, blind_range:List[float], categories:Optional[List[str]]=None):
         self.model.create_blind_range(blind_range, categories)
         sideband_range_name = self.model.get_sideband_range_name()
-        self.minimizer.configure_nll(range=sideband_range_name, update=True)
+        self.minimizer.configure_nll(range=sideband_range_name, split_range=True, update=True)
         self._use_blind_range = True
         
     def unset_blind_range(self):
         self.minimizer.nll = None
         self.minimizer.nll_commands.pop("RangeWithName", None)
+        self.minimizer.nll_commands.pop("SplitRange", None)
         self.stdout.info("INFO: Blind range removed from list of  NLL commands. NLL is reset.")
         self._use_blind_range = False
         
@@ -159,7 +164,21 @@ class AnalysisObject(AbstractObject):
             else:
                 self.model.workspace.loadSnapshot(snapshot_name)
                 self.stdout.debug(f"DEBUG: Loaded snapshot \"{snapshot_name}\"")
-                
+    
+    def get_variables(self, name:str):
+        if name == "nuis":
+            variables = self.model.nuisance_parameters
+        elif name == "globs":
+            variables = self.model.global_observables
+        elif name == "core":
+            variables = ROOT.RooArgSet()
+            variables.add(self.model.nuisance_parameters)
+            variables.add(self.model.global_observables)
+            variables.add(self.model.pois)
+        else:
+            raise RuntimeError("unknown name for variable set")
+        return variables
+    
     def save_snapshot(self, snapshot_name:Optional[str]=None, 
                       variables:Optional[Union[ROOT.RooArgSet, str]]=None):
         if snapshot_name is not None:
@@ -167,10 +186,7 @@ class AnalysisObject(AbstractObject):
                 self.model.workspace.saveSnapshot(snapshot_name, self.model.workspace.allVars())
             else:
                 if isinstance(variables, str):
-                    if variables == "nuis":
-                        variables = self.model.nuisance_parameters
-                    elif variables == "globs":
-                        variables = self.model.global_observables
+                    variables = self.get_variables(variables)
                 self.model.workspace.saveSnapshot(snapshot_name, variables)
             self.stdout.debug(f"DEBUG: Saved snapshot \"{snapshot_name}\"")
         
