@@ -34,7 +34,7 @@ class AsymptoticCLs(AnalysisObject):
                  ws_name:Optional[str]=None, mc_name:Optional[str]=None,
                  snapshot_name:Optional[str]=None, timer:bool=False,
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
-                 eps:float=1.0, strategy:int=1, print_level:int=-1, 
+                 eps:float=1.0, retry:int=0, strategy:int=1, print_level:int=-1, 
                  num_cpu:int=1, offset:bool=True, optimize:int=2,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1,
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
@@ -59,6 +59,7 @@ class AsymptoticCLs(AnalysisObject):
             'minimizer_type': minimizer_type,
             'minimizer_algo': minimizer_algo,
             'eps': eps,
+            'retry': retry,
             'strategy': strategy,
             'num_cpu': num_cpu,
             'offset': offset,
@@ -75,9 +76,7 @@ class AsymptoticCLs(AnalysisObject):
             'int_bin_precision': int_bin_precision,
             'verbosity': verbosity
         }
-
         super().__init__(**config)
-
         self.do_blind = do_blind
         self.CL = CL
         self.precision = precision
@@ -201,7 +200,9 @@ class AsymptoticCLs(AnalysisObject):
         qmu = 2*(nll_value - nll_muhat)
         if qmu < 0 :
             raise RuntimeError("qmu is negative which means the globally minimized "
-                               "NLL is larger then the NLL of interest")
+                               "NLL is larger then the NLL of interest; this can happen "
+                               "when the true global minimum is outside the valid range "
+                               "of the parameter of interest")
         return qmu
 
     def do_predictive_fit(self, nll:"ROOT.RooNLLVar", mu1:float, mu2:float, mu:float):
@@ -234,7 +235,7 @@ class AsymptoticCLs(AnalysisObject):
         # case for observed limit
         if (nll not in self.nll_maps) or ('nll_mu_hat' not in self.nll_maps[nll]):
             nll_val = self.get_nll_val(nll)
-            mu_hat = self.poi.getVal()           
+            mu_hat = self.poi.getVal()
             self.save_nll_snapshot(nll, mu_hat)
             if (mu_hat < 0) and (self.do_tilde):
                 self.set_poi_value(0)
@@ -285,6 +286,7 @@ class AsymptoticCLs(AnalysisObject):
                 self.do_predictive_fit(nll, mu_pre2, mu_pre, mu_guess)
             else:
                 self.load_nll_snapshot(asimov_0_nll, mu_pre)
+                
             qmu = self.get_qmu(nll, mu_guess)
             sigma_guess = self.LimitTool.getSigma(mu_guess, mu_hat, qmu)
             self.save_nll_snapshot(nll, mu_guess)
@@ -299,6 +301,7 @@ class AsymptoticCLs(AnalysisObject):
                         self.do_predictive_fit(nll, mu_pre2, mu_pre, mu_guess)
                 else:
                     self.load_nll_snapshot(asimov_0_nll, mu_pre)
+
                 qmuA = self.get_qmu(asimov_0_nll, mu_guess)
                 sigma_b = self.LimitTool.getSigma(mu_guess, 0, qmuA)
                 self.save_nll_snapshot(asimov_0_nll, mu_guess)
@@ -488,7 +491,6 @@ class AsymptoticCLs(AnalysisObject):
         obs_nll = self.create_nll(self.data)
         self.nll_maps[obs_nll] = {"dataset": self.data, "snapshot": self.nom_glob_name}
         self.dataset_maps[self.data] = obs_nll
-        
         self.save_snapshot(self.nom_glob_name, variables="globs")
         self.save_snapshot(self.nom_nuis_name, variables="nuis")
         
@@ -514,6 +516,8 @@ class AsymptoticCLs(AnalysisObject):
         limits = approx_limits.copy()
         
         sigma = med_limit/math.sqrt(3.84)
+        poi_range_tmp = self.poi.getRange()
+        # restrict poi range for computing sigma bands
         self.poi.setRange(-5*sigma, 5*sigma)
         
         # compute better sigma bands
@@ -529,6 +533,8 @@ class AsymptoticCLs(AnalysisObject):
         
         # compute observed limit
         self.load_conditional_snapshot(0, target="nuis")
+        # relax the range for observed limit
+        self.poi.setRange(poi_range_tmp[0], poi_range_tmp[1])
         obs_limit = 0 if self.do_blind else self.get_limit(obs_nll, med_limit, 'obs')
         limits['obs'] = obs_limit
         
