@@ -143,7 +143,27 @@ class ExtendedMinimizer(AbstractObject):
                 self.stdout.info(f"INFO: Using the range \"{range_name}\" for NLL calculation")
         if dataset is None:
             dataset = self.data
-        nll = self.pdf.createNLL(dataset, *nll_commands)
+        if len(nll_commands) <= 6:
+            nll = self.pdf.createNLL(dataset, *nll_commands)
+        # bug: can't have more than 6 arguments
+        elif len(nll_commands) == 7:
+            reduced_command_list = [i for i in nll_commands if i.GetName() != 'NumCPU']
+            self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
+                                "Will remove `NumCPU` from the command list")
+            if len(reduced_command_list) <= 6:
+                nll = self.pdf.createNLL(dataset, *reduced_command_list)
+            else:
+                raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+        elif len(nll_commands) == 8:
+            reduced_command_list = [i for i in nll_commands if i.GetName() not in ['NumCPU', 'IntegrateBins']]
+            self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
+                                "Will remove `NumCPU` and `IntegrateBins` from the command list")
+            if len(reduced_command_list) <= 6:
+                nll = self.pdf.createNLL(dataset, *reduced_command_list)
+            else:
+                raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+        else:
+            raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
         return nll
             
     def create_nll(self, nll_commands:List["ROOT.RooCmdArg"]=None, 
@@ -182,13 +202,15 @@ class ExtendedMinimizer(AbstractObject):
             commands.append(ROOT.RooFit.Offset(kwargs['offset']))
         if 'range' in kwargs:
             commands.append(ROOT.RooFit.Range(kwargs['range']))
+        if ('split_range' in kwargs) and (kwargs['split_range']):
+            commands.append(ROOT.RooFit.SplitRange())
         if ('batch_mode' in kwargs) and hasattr(ROOT.RooFit, "BatchMode"):
-            commands.append(ROOT.RooFit.BatchMode(batch_mode))
+            commands.append(ROOT.RooFit.BatchMode(kwargs['batch_mode']))
         if ('int_bin_precision' in kwargs) and hasattr(ROOT.RooFit, "IntegrateBins"):
             commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))
         if constrain is not None:
             commands.append(ROOT.RooFit.Constrain(constrain))
-            self.stdout.warning("Use of `Constrain` option from createNLL is not recommended")
+            self.stdout.warning("WARNING: Use of `Constrain` option from createNLL is not recommended", "red")
         if global_observables is not None:
             commands.append(ROOT.RooFit.GlobalObservables(global_observables))
         command_dict = {}
@@ -215,6 +237,8 @@ class ExtendedMinimizer(AbstractObject):
             self.nll_commands.update(command_dict)
         else:
             self.nll_commands = command_dict
+        if ('split_range' in kwargs) and (not kwargs['split_range']):
+            self.nll_commands.pop("SplitRange", None)
         self.nll = None
     
     def configure(self, **kwargs):
@@ -248,7 +272,7 @@ class ExtendedMinimizer(AbstractObject):
             self.create_nll()
         else:
             self.nll = nll
-        
+
         if self.cond_set.size() > 0:
             attached_set = self.nll.getVariables()
             for cond in self.cond_set:
