@@ -35,6 +35,7 @@ class ExtendedModel(AbstractObject):
         'weight': 'weightVar',
         'dataset_args': 'obsAndWeight',
         'asimov': 'asimovData_{mu}',
+        'asimov_no_poi': 'asimovData',
         'channel_asimov': 'combAsimovData_{label}',
         'nll_snapshot': '{nll_name}_{mu}',
         'range_sideband_low': 'SBLo',
@@ -182,25 +183,29 @@ class ExtendedModel(AbstractObject):
                 self.stdout.warning(f'WARNING: Failed to load snapshot "{snapshot_name}"')
             
     def initialize(self):
-        if not os.path.exists(self.fname):
-            raise FileNotFoundError('workspace file {} does not exist'.format(self.fname))
-        self.stdout.info('INFO: Opening file "{}"'.format(self.fname))
-        file = ROOT.TFile(self.fname) 
-        if (not file):
-            raise RuntimeError("Something went wrong while loading the root file: {}".format(self.fname))
-        # load workspace
-        if self.ws_name is None:
-            ws_names = [i.GetName() for i in file.GetListOfKeys() if i.GetClassName() == 'RooWorkspace']
-            if not ws_names:
-                raise RuntimeError("No workspaces found in the root file: {}".format(self.fname))
-            if len(ws_names) > 1:
-                self.stdout.warning("WARNING: Found multiple workspace instances from the root file: {}. Available workspaces"
-                      " are \"{}\". Will choose the first one by default".format(self.fname, ','.join(ws_names)))
-            self.ws_name = ws_names[0]
-
-        ws = file.Get(self.ws_name)
+        if isinstance(self.fname, str):
+            if not os.path.exists(self.fname):
+                raise FileNotFoundError('workspace file {} does not exist'.format(self.fname))
+            self.stdout.info('INFO: Opening file "{}"'.format(self.fname))
+            file = ROOT.TFile(self.fname) 
+            if (not file):
+                raise RuntimeError("Something went wrong while loading the root file: {}".format(self.fname))
+            # load workspace
+            if self.ws_name is None:
+                ws_names = [i.GetName() for i in file.GetListOfKeys() if i.GetClassName() == 'RooWorkspace']
+                if not ws_names:
+                    raise RuntimeError("No workspaces found in the root file: {}".format(self.fname))
+                if len(ws_names) > 1:
+                    self.stdout.warning("WARNING: Found multiple workspace instances from the root file: {}. Available workspaces"
+                          " are \"{}\". Will choose the first one by default".format(self.fname, ','.join(ws_names)))
+                self.ws_name = ws_names[0]
+            ws = file.Get(self.ws_name)
+        elif isinstance(self.fname, ROOT.RooWorkspace):
+            file = None
+            ws = self.fname
         if not ws:
             raise RuntimeError('failed to load workspace "{}"'.format(self.ws_name))
+        self.ws_name = ws.GetName()
         self.stdout.info('INFO: Loaded workspace "{}"'.format(self.ws_name))
         # load model config
         if self.mc_name is None:
@@ -248,7 +253,7 @@ class ExtendedModel(AbstractObject):
             self.data_name = data_names[0]
         data = ws.data(self.data_name)
         if not data:
-            raise RuntimeError('Failed to load dataset')
+            raise RuntimeError(f'Failed to load dataset \"{self.data_name}\"')
         self.stdout.info('INFO: Loaded dataset "{}" from workspace'.format(data.GetName()))
                 
         # load nuisance parameters
@@ -710,9 +715,9 @@ class ExtendedModel(AbstractObject):
         """
         if len(blind_range) != 2:
             raise ValueError("invalid format for blind range, must be list of the form [xmin, xmax]")
-        range_name_SBLo = self._DEFAULT_NAMES_['range_sideband_low']
+        range_name_SBLo  = self._DEFAULT_NAMES_['range_sideband_low']
         range_name_Blind = self._DEFAULT_NAMES_['range_blind']
-        range_name_SBHi = self._DEFAULT_NAMES_['range_sideband_high']
+        range_name_SBHi  = self._DEFAULT_NAMES_['range_sideband_high']
         padding = max([len(range_name_SBLo), len(range_name_Blind), len(range_name_SBHi)]) + 2
         blind_min = blind_range[0]
         blind_max = blind_range[1]
@@ -727,13 +732,17 @@ class ExtendedModel(AbstractObject):
             obs_max = obs_range.second
             if (blind_max <= blind_min) or (blind_max > obs_max) or (blind_min < obs_min):
                 raise ValueError(f"invalid blinding range provided: min={blind_min}, max={blind_max}")
-            obs.setRange(f"{range_name_SBLo}", obs_min, blind_min)
-            obs.setRange(f"{range_name_Blind}", blind_min, blind_max)
-            obs.setRange(f"{range_name_SBHi}", blind_max, obs_max)
+            _range_name_SBLo  = f"{range_name_SBLo}_{category}"
+            _range_name_Blind = f"{_range_name_Blind}_{category}"
+            _range_name_SBHi  = f"{_range_name_SBHi}_{category}"            
+            obs.setRange(_range_name_SBLo, obs_min, blind_min)
+            obs.setRange(_range_name_Blind, blind_min, blind_max)
+            obs.setRange(_range_name_SBHi, blind_max, obs_max)
+            cat_padding = padding + len(category)
             self.stdout.info(f"INFO: The following ranges are defined for the observable \"{obs_name}\"")
-            self.stdout.info(f"\t{range_name_SBLo.ljust(padding)}: [{obs_min}, {blind_min}]")
-            self.stdout.info(f"\t{range_name_Blind.ljust(padding)}: [{blind_min}, {blind_max}]")
-            self.stdout.info(f"\t{range_name_SBHi.ljust(padding)}: [{blind_max}, {obs_max}]")
+            self.stdout.info(f"\t{_range_name_SBLo.ljust(cat_padding)}: [{obs_min}, {blind_min}]")
+            self.stdout.info(f"\t{_range_name_Blind.ljust(cat_padding)}: [{blind_min}, {blind_max}]")
+            self.stdout.info(f"\t{_range_name_SBHi.ljust(cat_padding)}: [{blind_max}, {obs_max}]")
         return None
     
     def get_sideband_range_name(self):
@@ -956,7 +965,7 @@ class ExtendedModel(AbstractObject):
             self.stdout.debug("set glob {} to val {}".format(globs.GetName(), globs.getVal()))
         """
 
-    def generate_asimov(self, poi_name:str, poi_val:Optional[float]=None, 
+    def generate_asimov(self, poi_name:Optional[str]=None, poi_val:Optional[float]=None, 
                         poi_profile:Optional[float]=None,
                         do_fit:bool=True,
                         modify_globs:bool=True,
@@ -1044,6 +1053,7 @@ class ExtendedModel(AbstractObject):
             names.update(snapshot_names)
         if asimov_name is not None:
             names['asimov'] = asimov_name
+            names['asimov_no_poi'] = asimov_name
         if channel_asimov_name is not None:
             names['channel_asimov'] = channel_asimov_name
         nom_vars_name = names['nominal_vars']
@@ -1052,7 +1062,10 @@ class ExtendedModel(AbstractObject):
         con_glob_name = names['conditional_globs']
         con_nuis_name = names['conditional_nuis']
 
-        poi = self.get_poi(poi_name)
+        if poi_name is None:
+            poi = None
+        else:
+            poi = self.get_poi(poi_name)
         
         # take snapshot of initial states of all variables
         ws.saveSnapshot(nom_vars_name, self.workspace.allVars())
@@ -1080,38 +1093,44 @@ class ExtendedModel(AbstractObject):
             else:
                 raise ValueError(f"unsupported constraint option: {constraint_option}")
             if isinstance(nll_options, dict):
-                minimizer.configure_nll(all_nuis, all_globs, **nll_options)
+                minimizer.configure_nll(None, all_globs, **nll_options)
             elif isinstance(nll_options, list):
                 minimizer.set_nll_commands(nll_options)
             else:
                 raise ValueError(f"unsupported nll options format")
-            if poi_profile is not None:
-                # conditional mle
-                poi.setVal(poi_profile)
-                poi.setConstant(1)
-            else:
-                # unconditional mle
-                poi.setConstant(0)
+            if poi:
+                if poi_profile is not None:
+                    # conditional mle
+                    poi.setVal(poi_profile)
+                    poi.setConstant(1)
+                else:
+                    # unconditional mle
+                    poi.setConstant(0)
             minimizer.minimize()
-
-        if poi_val is not None:
-            poi.setVal(poi_val)
-        poi.setConstant(0)
-        poi_val = poi.getVal()
+        
+        if poi:
+            if poi_val is not None:
+                poi.setVal(poi_val)
+            poi.setConstant(0)
+            poi_val = poi.getVal()
         
         # match values of global observables to the corresponding NPs
         if modify_globs:
             self.match_globs()
 
-        if do_fit:
-            ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_profile)), all_globs)
-            ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_profile)), all_nuis)
-        else:
-            ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_val)), all_globs)
-            ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_val)), all_nuis)
+        if poi:
+            if do_fit:
+                ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_profile)), all_globs)
+                ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_profile)), all_nuis)
+            else:
+                ws.saveSnapshot(con_glob_name.format(mu=pretty_value(poi_val)), all_globs)
+                ws.saveSnapshot(con_nuis_name.format(mu=pretty_value(poi_val)), all_nuis)
 
-        asimov_data_name = names['asimov'].format(mu=pretty_value(poi_val), 
-                                                  mu_cond=pretty_value(poi_profile))
+            asimov_data_name = names['asimov'].format(mu=pretty_value(poi_val),
+                                                      mu_cond=pretty_value(poi_profile))
+        else:
+            asimov_data_name = names['asimov_no_poi']
+            
         channel_asimov_data_name = names['channel_asimov']
         sim_pdf = self.pdf
         if not isinstance(sim_pdf, ROOT.RooSimultaneous):
@@ -1338,18 +1357,18 @@ class ExtendedModel(AbstractObject):
             binnings[category] = {}
             bin_range = category_map[category]['bin_range']
             if bins is None:
-                bins = category_map[category]['bins']
+                _bins = category_map[category]['bins']
             elif isinstance(bins, dict):
-                bins = bins.get(category, None)
-                if bins is None:
+                _bins = bins.get(category, None)
+                if _bins is None:
                     raise RuntimeError(f"binning not specified for the category \"{category}\"")
             elif isinstance(bins, int):
-                bins = bins
+                _bins = bins
             else:
                 raise RuntimeError(f"invalid binning format: {bins}")
-            bin_width = round((bin_range[1] - bin_range[0]) / bins, 8)
+            bin_width = round((bin_range[1] - bin_range[0]) / _bins, 8)
             binnings[category]['bin_range'] = bin_range
-            binnings[category]['bins'] = bins
+            binnings[category]['bins'] = _bins
             binnings[category]['bin_width'] = bin_width
         return binnings
     
@@ -1372,26 +1391,43 @@ class ExtendedModel(AbstractObject):
             x = x[ind]
             y = dataset_values['weight'][mask][ind]
             default_bins = category_map[cat]['bins']
+            ghost  = False
             if np.all(y == 1.):
                 binned = False
-            elif len(x) == default_bins:
-                binned = True
             else:
-                raise RuntimeError(f"detected dataset with invalid binning")
+                # check if the event with non-unity weight are from the ghost
+                y_with_ghost_removed = y[y > 1e-8]
+                if np.all(y_with_ghost_removed == 1.):
+                    binned = False
+                    ghost  = True
+                elif len(x) == default_bins:
+                    binned = True
+                else:
+                    raise RuntimeError(f"detected dataset with invalid binning")
             bins = binnings[cat]['bins']
             if binned:
                 if  (bins != default_bins):
+                    from pdb import set_trace
+                    set_trace()
                     raise RuntimeError(f"cannot change binning of binned dataset ({dataset.GetName()}, cat = {cat}): "
                                        f"original binning = {default_bins}, requested binning = {bins}")
                 distributions[cat]['x'] = x
                 distributions[cat]['y'] = y
             else:
                 bin_range = binnings[cat]['bin_range']
-                hist, bin_edges = np.histogram(x, bins=bins, range=(bin_range[0], bin_range[1]))
-                bin_centers = (bin_edges[1:] + bin_edges[:-1])/2
-                distributions[cat]['x'] = bin_centers
-                distributions[cat]['y'] = hist
-                bin_errors = TH1.GetPoissonError(hist)
+                if not ghost:
+                    hist, bin_edges = np.histogram(x, bins=bins, range=(bin_range[0], bin_range[1]))
+                    bin_centers = (bin_edges[1:] + bin_edges[:-1])/2
+                    distributions[cat]['x'] = bin_centers
+                    distributions[cat]['y'] = hist
+                else:
+                    ghost_idx = y < 1e-8
+                    hist, bin_edges = np.histogram(x[~ghost_idx], bins=bins, range=(bin_range[0], bin_range[1]))
+                    hist_g, _ = np.histogram(x[ghost_idx], bins=bins, range=(bin_range[0], bin_range[1]), weights=y[ghost_idx])
+                    bin_centers = (bin_edges[1:] + bin_edges[:-1])/2
+                    distributions[cat]['x'] = bin_centers
+                    distributions[cat]['y'] = hist + hist_g
+                bin_errors = TH1.GetPoissonError(distributions[cat]['y'])
                 distributions[cat]['yerrlo'] = bin_errors['lo']
                 distributions[cat]['yerrhi'] = bin_errors['hi']
         return distributions
