@@ -80,7 +80,7 @@ class NuisanceParameterPull(object):
                    fix_param:Optional[str]=None, profile_param:Optional[str]=None, binned:bool=True,
                    workspace:Optional[str]=None, model_config:Optional[str]=None,
                    minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
-                   precision:float=0.001, eps:float=1.0, strategy:int=0, print_level:int=1,
+                   precision:float=0.001, eps:float=1.0, retry:int=0, strategy:int=0, print_level:int=1,
                    num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                    fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                    max_iters:int=-1, batch_mode:bool=False, int_bin_precision:float=-1.,
@@ -150,6 +150,7 @@ class NuisanceParameterPull(object):
             'opt_const'        : optimize,
             'precision'        : precision,
             'eps'              : eps,
+            'retry'            : retry,
             'max_calls'        : max_calls,
             'max_iters'        : max_iters,
         }
@@ -274,10 +275,11 @@ class NuisanceParameterPull(object):
                   snapshot:str='nominalNuis', outdir:str='output', profile:Optional[str]=None,
                   fix:Optional[str]=None, workspace:Optional[str]=None, model_config:Optional[str]=None,
                   minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, 
-                  binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
-                  strategy:int=0, print_level:int=1, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, 
-                  optimize:int=2, parameter:str="", max_calls:int=-1, max_iters:int=-1, batch_mode:bool=False, 
-                  int_bin_precision:float=-1.,parallel:int=0, cache:bool=True, exclude:str='', **kwargs):
+                  binned:bool=1, precision:float=0.001, eps:float=1.0, retry:int=0, log_level:str='INFO',
+                  eigen:bool=False, strategy:int=0, print_level:int=1, fix_cache:bool=True, fix_multi:bool=True,
+                  offset:bool=True, optimize:int=2, parameter:str="", max_calls:int=-1, max_iters:int=-1,
+                  batch_mode:bool=False, int_bin_precision:float=-1.,parallel:int=0, cache:bool=True,
+                  exclude:str='', **kwargs):
         
         # configure default minimizer options
         ExtendedMinimizer._configure_default_minimizer_options(minimizer_type, minimizer_algo,
@@ -310,11 +312,11 @@ class NuisanceParameterPull(object):
         arguments = (repeat(input_file), repeat(data), repeat(snapshot), nuis_names, 
                      repeat(poi), repeat(fix), repeat(profile), repeat(binned),
                      repeat(workspace), repeat(model_config), repeat(minimizer_type), 
-                     repeat(minimizer_algo), repeat(precision), repeat(eps), repeat(strategy),
-                     repeat(print_level), repeat(num_cpu), repeat(offset), repeat(optimize), 
-                     repeat(eigen), repeat(fix_cache), repeat(fix_multi), repeat(max_calls), 
-                     repeat(max_iters), repeat(batch_mode), repeat(int_bin_precision),
-                     repeat(outdir), repeat(cache), logfile_paths)
+                     repeat(minimizer_algo), repeat(precision), repeat(eps), repeat(retry),
+                     repeat(strategy), repeat(print_level), repeat(num_cpu), repeat(offset),
+                     repeat(optimize), repeat(eigen), repeat(fix_cache), repeat(fix_multi),
+                     repeat(max_calls), repeat(max_iters), repeat(batch_mode),
+                     repeat(int_bin_precision), repeat(outdir), repeat(cache), logfile_paths)
         common_utils.execute_multi_tasks(self._run_pulls, *arguments, parallel=parallel)
 
         
