@@ -27,8 +27,10 @@ class RooProcBaseAction(object):
                 formatted_parameters[k] = None
                 continue
             k_literals = re.findall(r"\${(\w+)}", k)
+            is_list = False
             if isinstance(v, list):
                 v = '__SEPARATOR__'.join(v)
+                is_list = True
             v_literals = re.findall(r"\${(\w+)}", v)
             all_literals = set(k_literals).union(set(v_literals))
             for literal in all_literals:
@@ -40,7 +42,7 @@ class RooProcBaseAction(object):
             for literal in v_literals:
                 substitute = global_vars[literal]
                 v = v.replace("${" + literal + "}", str(substitute))
-            if '__SEPARATOR__' in v:
+            if is_list:
                 v = v.split("__SEPARATOR__")
             formatted_parameters[k] = v
         return formatted_parameters
@@ -220,6 +222,16 @@ class RooProcDefine(RooProcRDFAction):
         rdf_next = rdf.Define(name, expression)
         return rdf_next
     
+class RooProcRedefine(RooProcDefine):
+    
+    def _execute(self, rdf, **params):
+        name = params['name']
+        expression = params['expression']
+        if not hasattr(rdf, "Redefine"):
+            raise RuntimeError("RDF.Redefine action requires ROOT version >= 6.26/00")
+        rdf_next = rdf.Redefine(name, expression)
+        return rdf_next
+    
 class RooProcFilter(RooProcRDFAction):
     def __init__(self, expression:str, name:Optional[str]=None):
         super().__init__(expression=expression,
@@ -277,7 +289,7 @@ class RooProcSave(RooProcHybridAction):
             for column in columns:
                 save_columns += [c for c in all_columns if fnmatch.fnmatch(c, column)]
             save_columns = list(set(save_columns))
-            self.makedirs(filename)
+            self.makedirs(filename)            
             rdf_next = rdf.Snapshot(treename, filename, save_columns)
         processor.stdout.info(f"INFO: Writing output to `{filename}`.")
         return rdf_next, processor
@@ -433,6 +445,7 @@ ACTION_MAP = {
     'ALIAS': RooProcAlias,
     'SAFEALIAS': RooProcSafeAlias,
     'DEFINE': RooProcDefine,
+    'REDEFINE': RooProcRedefine,
     'FILTER': RooProcFilter,
     'SAVE': RooProcSave,
     'REPORT': RooProcReport,
