@@ -354,8 +354,8 @@ class NPRankingPlot:
             prefix = 'impact_{}'.format(it)
             # retrieve the impact data
             if relative:
-                impact_down = data['{}_down'.format(prefix)].values / data['poi_hat'].values
-                impact_up = data['{}_up'.format(prefix)].values / data['poi_hat'].values           
+                impact_down = data['{}_down'.format(prefix)].values / np.abs(data['poi_hat'].values)
+                impact_up = data['{}_up'.format(prefix)].values / np.abs(data['poi_hat'].values)
             else:
                 impact_down = data['{}_down'.format(prefix)].values
                 impact_up = data['{}_up'.format(prefix)].values
