@@ -192,4 +192,17 @@ def print_pdf_structure(pdf:"ROOT.RooAbsPdf", level:int=0, show_address=False):
         for pdf_i in pdf_list:
             if pdf_i == pdf:
                 continue
-            print_pdf_structure(pdf_i, level+1, show_address=show_address)
\ No newline at end of file
+            print_pdf_structure(pdf_i, level+1, show_address=show_address)
+                     
+def get_correlation_matrix(roofit_result, lib:str="pandas"):
+    correlation_hist = roofit_result.correlationHist()
+    if lib.lower() == "pandas":
+        from quickstats.interface.root import TH2
+        df = TH2.correlationHist_to_dataframe(correlation_hist)
+        correlation_hist.Delete()
+        return df
+    elif lib.lower() == "root":
+        return correlation_hist
+    else:
+        raise ValueError(f"unsupported library: {lib} (available options: \"root\", \"pandas\")")
+    
\ No newline at end of file
