@@ -39,15 +39,15 @@ def load_macro(name:str):
         return None
     class_loaded = hasattr(ROOT, name)
     if class_loaded:
-    	return None
+        return None
     macros_dir = os.path.join(quickstats.macro_path, 'macros', name)
     macros_path = os.path.join(macros_dir, name + '_cxx')
     if not os.path.exists(macros_path + '.so'):
         return compile_macro(name)
     result = ROOT.gSystem.Load(macros_path)
     if (result != 0) and (result != 1):
-        raise RuntimeError("Shared library for the macro {} is incompatible with the current pyROOT version. "
-                           "Please recompile by typing \"quickstats compile\".".format(name))
+        raise RuntimeError(f"Shared library for the macro {name} is incompatible with the current pyROOT version. "
+                           "Please recompile by typing \"quickstats compile\".")
     return result
 
 
